@@ -34,7 +34,7 @@ BEGIN_RCPP
     // Compute np, number of unique clients
     // algorithm assumes cases clustered by unique client
     IntegerVector dpr = diff(pr);
-    icolvec diffpersons(dpr.begin(), nc - 1, false);
+    Col<int32_t> diffpersons(dpr.begin(), nc - 1, false);
     int np = accu(diffpersons) + 1;
     /* int np = accumulate(dpr.begin,dpr.end,1); */
 
@@ -46,7 +46,7 @@ BEGIN_RCPP
     mat xmat(Xr.begin(), nc, nf, false);
     mat zmat(Zr.begin(), nc, nr, false);
     colvec y(yr.begin(), nc, false);
-    icolvec persons(pr.begin(), nc, false);
+    Col<int32_t> persons(pr.begin(), nc, false);
 
     // set up data objects indexed by clustering unit
     field<mat> zsplit(np,1); field<mat> ztzsplit(np,1);
@@ -85,7 +85,7 @@ BEGIN_RCPP
     rowvec taub(nr); taub.ones();
     /* cluster capture variables */
     IntegerVector ss = seq_len(np);
-    icolvec s(ss.begin(), np, false);
+    Col<int32_t> s(ss.begin(), np, false);
     s -= 1; s = shuffle(s);
     int M = np; /* each person initialized with their own cluster */
     icolvec num(M); num.ones();
