@@ -43,7 +43,7 @@ BEGIN_RCPP
     // Compute np, number of unique clients
     // algorithm assumes cases clustered by unique client
     IntegerVector dpr = diff(pr);
-    icolvec diffpersons(dpr.begin(), nc - 1, false);
+    Col<int32_t> diffpersons(dpr.begin(), nc - 1, false);
     int np = accu(diffpersons) + 1;
     /* int np = accumulate(dpr.begin,dpr.end,1); */
 
@@ -59,8 +59,8 @@ BEGIN_RCPP
     mat omega(Or.begin(), ns, ns, false);
     colvec y(yr.begin(), nc, false);
     colvec omegaplus(opr.begin(), ns, false);
-    icolvec groups(gr.begin(), ns, false);
-    icolvec persons(pr.begin(), nc, false);
+    Col<int32_t> groups(gr.begin(), ns, false);
+    Col<int32_t> persons(pr.begin(), nc, false);
 
     // pre-compute quadratic product of design matrix for use in sampling
     field<mat> zsplit(np,1); field<mat> ztzsplit(np,1);
