@@ -46,7 +46,7 @@ BEGIN_RCPP
     // Compute np, number of unique clients
     // algorithm assumes cases clustered by unique client
     IntegerVector dpr = diff(pr);
-    icolvec diffpersons(dpr.begin(), nc - 1, false);
+    Col<int32_t> diffpersons(dpr.begin(), nc - 1, false);
     int np = accu(diffpersons) + 1;
     /* int np = accumulate(dpr.begin,dpr.end,1); */
 
@@ -63,7 +63,7 @@ BEGIN_RCPP
     colvec y(yr.begin(), nc, false);
     colvec omegaplus(opr.begin(), ns, false);
     // icolvec groups(gr.begin(), ns, false);
-    icolvec persons(pr.begin(), nc, false);
+    Col<int32_t> persons(pr.begin(), nc, false);
     // set up data objects indexed by clustering unit
     field<mat> zsplit(np,1); field<mat> ztzsplit(np,1);
     field<mat> xsplit(np,1); field<mat> wsplit(np,1);
